@@ -4,6 +4,7 @@
 # Created: 4/8/20
 from mtdata import log
 from mtdata.entry import Entry, Paper
+from typing import List
 
 
 class Index:
@@ -59,7 +60,7 @@ class Index:
 INDEX: Index = Index()
 
 
-def get_entries(langs=None, names=None, not_names=None):
+def get_entries(langs=None, names=None, not_names=None) -> List[Entry]:
     """
     :param langs: language pairs  to select eg ('en', 'de')
     :param names:  names to select
@@ -84,8 +85,9 @@ def get_entries(langs=None, names=None, not_names=None):
 
 def load_all():
     from mtdata.index import (statmt, paracrawl, tilde, literature, joshua_indian, globalvoices,
-                              unitednations, wikimatrix, other, neulab_tedtalks)
-    from mtdata.index.opus import opus_index, jw300
+                              unitednations, wikimatrix, other, neulab_tedtalks, elrc_share,
+                              ai4bharat)
+    from mtdata.index.opus import opus_index, jw300, opus100
 
     counts = {}
     subsets = [
@@ -97,9 +99,12 @@ def load_all():
         ('UnitedNations', unitednations.load_all),
         ('OPUS', opus_index.load_all),
         ('OPUS_JW300', jw300.load_all),
+        ('OPUS100', opus100.load_all),
         ('WikiMatrix', wikimatrix.load_all),
         ('Other', other.load_all),
         ('Neulab_TEDTalksv1', neulab_tedtalks.load_all),
+        ('ELRC-SHARE', elrc_share.load_all),
+        ('AI4Bharat', ai4bharat.load_all),
     ]
     for name, loader in subsets:
         n = len(INDEX)
