@@ -226,6 +226,54 @@ def load(index: Index):
             index.add_entry(Entry((l1, l2), name=name, filename='wmt20dev.tgz', in_paths=[src, ref],
                                   url='http://data.statmt.org/wmt20/translation-task/dev.tgz',
                                   cite=cite))
+
+    #### WMT 20 Tests
+    url = "http://data.statmt.org/wmt20/translation-task/test.tgz"
+    wmt20_cite = """@inproceedings{barrault-etal-2020-findings,
+    title = "Findings of the 2020 Conference on Machine Translation ({WMT}20)",
+    author = {Barrault, Lo{\"\i}c  and
+      Biesialska, Magdalena  and
+      Bojar, Ond{\v{r}}ej  and
+      Costa-juss{\`a}, Marta R.  and
+      Federmann, Christian  and
+      Graham, Yvette  and
+      Grundkiewicz, Roman  and
+      Haddow, Barry  and
+      Huck, Matthias  and
+      Joanis, Eric  and
+      Kocmi, Tom  and
+      Koehn, Philipp  and
+      Lo, Chi-kiu  and
+      Ljube{\v{s}}i{\'c}, Nikola  and
+      Monz, Christof  and
+      Morishita, Makoto  and
+      Nagata, Masaaki  and
+      Nakazawa, Toshiaki  and
+      Pal, Santanu  and
+      Post, Matt  and
+      Zampieri, Marcos},
+    booktitle = "Proceedings of the Fifth Conference on Machine Translation",
+    month = nov,
+    year = "2020",
+    address = "Online",
+    publisher = "Association for Computational Linguistics",
+    url = "https://www.aclweb.org/anthology/2020.wmt-1.1",
+    pages = "1--55",
+    }"""
+    for _pref, pairs in {
+        "": ["csen", "deen", "defr", "encs", "ende", "eniu", "enja", "enkm", "enpl", "enps",
+             "enru", "enta", "enzh", "frde", "iuen", "jaen", "kmen", "plen", "psen", "ruen",
+             "taen", "zhen"],
+        "B": ["deen", "ende", "enzh", "ruen", "zhen"]}.items():
+        for pair in pairs:
+            l1, l2 = pair[:2], pair[2:]
+            name = f'newstest{_pref}2020'
+            f1 = f'sgm/{name}-{pair}-src.{l1}.sgm'
+            f2 = f'sgm/{name}-{pair}-ref.{l2}.sgm'
+            name = f'{name}_{pair}'  # name cant have -, so have an _ instead
+            index.add_entry(Entry((l1, l2), name=name, filename='wmt20tests.tgz', in_paths=[f1, f2],
+                                  in_ext='sgm', cite=wmt20_cite, url=url))
+
     # Multi parallel
     wmt_sets = {
         '2009': ['en', 'cs', 'de', 'es', 'fr'],
@@ -258,7 +306,6 @@ def load(index: Index):
 
     # ==== Europarl v10
     EP_v10 = "http://www.statmt.org/europarl/v10/training/europarl-v10.%s-%s.tsv.gz"
-    wmt20_cite = None  # TODO: update
     for pair in ['cs en', 'cs pl', 'de en', 'de fr', 'es pt', 'fi en', 'fr en', 'lt en', 'pl en']:
         l1, l2 = pair.split()
         index.add_entry(
@@ -300,3 +347,42 @@ def load(index: Index):
         entry = Entry(langs=('ps', 'en'), name=name, url=url, cite=wmt20_cite, in_paths=[ps, en],
                       filename='wmt20-psen-parallel.tgz', in_ext='txt')
         index.add_entry(entry)
+
+    for l2 in ['ps', 'km']:
+        url = f"http://data.statmt.org/wmt20/translation-task/ps-km/wmt20-sent.en-{l2}.xz"
+        entry = Entry(langs=('en', l2), name='paracrawl_v5_1', url=url, cite=wmt20_cite,
+                      ext='tsv.xz', cols=(0, 1))
+        index.add_entry(entry)
+
+    ccalign_cite = """@InProceedings{chaudhary-EtAl:2019:WMT,
+  author    = {Chaudhary, Vishrav  and  Tang, Yuqing  and  GuzmÃƒÂ¡n, Francisco  and  Schwenk, Holger  and  Koehn, Philipp},
+  title     = {Low-Resource Corpus Filtering Using Multilingual Sentence Embeddings},
+  booktitle = {Proceedings of the Fourth Conference on Machine Translation (Volume 3: Shared Task Papers, Day 2)},
+  month     = {August},
+  year      = {2019},
+  address   = {Florence, Italy},
+  publisher = {Association for Computational Linguistics},
+  pages     = {263--268},
+  url       = {http://www.aclweb.org/anthology/W19-5435}
+}"""
+    CC_ALIGNED = 'http://www.statmt.org/cc-aligned/sentence-aligned/{src}-{tgt}.tsv.xz'
+    tgts='es_XX et_EE fa_IR ff_NG fi_FI fr_XX gu_IN ha_NG he_IL hi_IN hr_HR ht_HT hu_HU hy_AM id_ID ig_NG is_IS it_IT ja_XX jv_ID ka_GE kg_AO kk_KZ km_KH kn_IN ko_KR ku_TR ky_KG lg_UG ln_CD lo_LA lt_LT lv_LV mg_MG mi_NZ mk_MK ml_IN mn_MN mr_IN ms_MY mt_MT my_MM ne_NP nl_XX no_XX ns_ZA ny_MW om_KE or_IN pa_IN pl_PL ps_AF pt_XX qa_MM qd_MM ro_RO ru_RU si_LK sk_SK sl_SI sn_ZW so_SO sq_AL sr_RS ss_SZ st_ZA su_ID sv_SE sw_KE sz_PL ta_IN te_IN tg_TJ th_TH ti_ET tl_XX tn_BW tr_TR ts_ZA tz_MA uk_UA ur_PK ve_ZA vi_VN wo_SN xh_ZA yo_NG zh_CN zh_TW zu_ZA zz_TR'.split()
+    srcs = 'af_ZA ak_GH am_ET ar_AR as_IN ay_BO az_AZ az_IR be_BY bg_BG bm_ML bn_IN br_FR bs_BA ca_ES cb_IQ cs_CZ cx_PH cy_GB da_DK de_DE el_GR'.split()
+    pairs = [('en_XX', tgt) for tgt in tgts] + [(src, 'en_XX') for src in srcs]
+    dont_know = {'qa', 'qd'}
+     # Cant find them in ISO 639-1:  https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
+     #                and lingo http://www.lingoes.net/en/translator/langcode.htm
+     #               and web-info https://wp-info.org/tools/languagecodes.php
+    unsupported = {'zh_TW', 'az_IR'}
+    # country locales are not supported; they create conflicts. keeping large ones instead
+    for src, tgt in pairs:
+        if src in unsupported or tgt in unsupported:
+            continue
+        l1, l2 = src.split('_')[0], tgt.split('_')[0]
+        if l1 in dont_know or l2 in dont_know:
+            # I dont know what language these are
+            continue
+        url = CC_ALIGNED.format(src=src, tgt=tgt)
+        entry = Entry(langs=(l1, l2), name='cc_aligned', url=url, cite=ccalign_cite,
+                      ext='tsv.xz', cols=(0, 1))
+        index.add_entry(entry)
